// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// %                                                                   %
// %   IsoCSG Library - version 0.6                                    %
// %                                                                   %
// %   iso_bcsg.inc - Variation with native CSG support and            %
// %                  automatic container calculation                  %
// %                                                                   %
// %   developed March 2002 by ABX <abx@abx.art.pl>                    %
// %                                                                   %
// %   based on isoCSG written June 2001 - March 2002                  %
// %   by Christoph Hormann <chris_hormann@gmx.de>                     %
// %                                                                   %
// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// %                                                                   %
// %   Feel free to use this file for your povray work, I encourage    %
// %   you to contact me if you have ideas for improvements.           %
// %                                                                   %
// %   This is an experimental version so syntax and used methods      %
// %   are subject to changes.                                         %
// %                                                                   %
// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

#ifdef(iso_BCSG_Inc_Temp)
// do nothing
#else
#declare iso_BCSG_Inc_Temp = version;

#ifdef(View_POV_Include_Stack)
#   debug "including iso_bcsg.inc\n"
#end

#ifndef(iso_CSG_Inc_Temp)
  #include "iso_csg.inc"
#end

#include "shapes.inc"

#declare IC_Min=<0,0,0>;
#declare IC_Max=<0,0,0>;

#ifndef (IC_Delta)        // constant for spacing between bounding box and object
  #declare IC_Delta=0.01;
#end

//-------------------------------------------------------------
// ----   CSG macros   ----------------------------------------
//-------------------------------------------------------------

#macro IC_BMerge2(_ICSG_fn_A, _ICSG_ob_A, _ICSG_fn_B, _ICSG_ob_B)
  IC_Merge2(function(x, y, z){ _ICSG_fn_A(x, y, z) },       // merge 2 objects
            function(x, y, z){ _ICSG_fn_B(x, y, z) }) ,
  merge { object{ _ICSG_ob_A } object{ _ICSG_ob_B } }
#end

#macro IC_BMerge3(_ICSG_fn_A, _ICSG_ob_A, _ICSG_fn_B, _ICSG_ob_B, _ICSG_fn_C, _ICSG_ob_C)
  IC_Merge3(function(x, y, z){ _ICSG_fn_A(x, y, z) },       // merge 3 objects
            function(x, y, z){ _ICSG_fn_B(x, y, z) },
            function(x, y, z){ _ICSG_fn_C(x, y, z) }) ,
  merge { object{ _ICSG_ob_A } object{ _ICSG_ob_B } object{ _ICSG_ob_C } }
#end

#macro IC_BMerge4(_ICSG_fn_A, _ICSG_ob_A, _ICSG_fn_B, _ICSG_ob_B, _ICSG_fn_C, _ICSG_ob_C, _ICSG_fn_D, _ICSG_ob_D)
  IC_Merge4(function(x, y, z){ _ICSG_fn_A(x, y, z) },       // merge 4 objects
            function(x, y, z){ _ICSG_fn_B(x, y, z) },
            function(x, y, z){ _ICSG_fn_C(x, y, z) },
            function(x, y, z){ _ICSG_fn_D(x, y, z) }) ,
  merge { object{ _ICSG_ob_A } object{ _ICSG_ob_B } object{ _ICSG_ob_C } object{ _ICSG_ob_D } }
#end

#macro IC_BMerge5(_ICSG_fn_A, _ICSG_ob_A, _ICSG_fn_B, _ICSG_ob_B, _ICSG_fn_C, _ICSG_ob_C, _ICSG_fn_D, _ICSG_ob_D, _ICSG_fn_E, _ICSG_ob_E)
  IC_Merge5(function(x, y, z){ _ICSG_fn_A(x, y, z) },       // merge 5 objects
            function(x, y, z){ _ICSG_fn_B(x, y, z) },
            function(x, y, z){ _ICSG_fn_C(x, y, z) },
            function(x, y, z){ _ICSG_fn_D(x, y, z) },
            function(x, y, z){ _ICSG_fn_E(x, y, z) }) ,
  merge { object{ _ICSG_ob_A } object{ _ICSG_ob_B } object{ _ICSG_ob_C } object{ _ICSG_ob_D } object{ _ICSG_ob_E } }
#end

#macro IC_BMerge_Array( _ICSG_Array , _ICSG_Common_Container )
  IC_Merge_Array( _ICSG_Array ) , _ICSG_Common_Container
#end

#macro IC_BIntersection2(_ICSG_fn_A, _ICSG_ob_A, _ICSG_fn_B, _ICSG_ob_B)
  IC_Intersection2(function(x, y, z){ _ICSG_fn_A(x, y, z) },     // intersection between 2 objects
                   function(x, y, z){ _ICSG_fn_B(x, y, z) }) ,
  intersection { object{ _ICSG_ob_A } object{ _ICSG_ob_B } }
#end

#macro IC_BIntersection3(_ICSG_fn_A, _ICSG_ob_A, _ICSG_fn_B, _ICSG_ob_B, _ICSG_fn_C, _ICSG_ob_C)
  IC_Intersection3(function(x, y, z){ _ICSG_fn_A(x, y, z) },     // intersection between 3 objects
                   function(x, y, z){ _ICSG_fn_B(x, y, z) },
                   function(x, y, z){ _ICSG_fn_C(x, y, z) }) ,
  intersection { object{ _ICSG_ob_A } object{ _ICSG_ob_B } object{ _ICSG_ob_C } }
#end

#macro IC_BIntersection4(_ICSG_fn_A, _ICSG_ob_A, _ICSG_fn_B, _ICSG_ob_B, _ICSG_fn_C, _ICSG_ob_C, _ICSG_fn_D, _ICSG_ob_D)
  IC_Intersection4(function(x, y, z){ _ICSG_fn_A(x, y, z) },     // intersection between 4 objects
                   function(x, y, z){ _ICSG_fn_B(x, y, z) },
                   function(x, y, z){ _ICSG_fn_C(x, y, z) },
                   function(x, y, z){ _ICSG_fn_D(x, y, z) }) ,
  intersection { object{ _ICSG_ob_A } object{ _ICSG_ob_B } object{ _ICSG_ob_C } object{ _ICSG_ob_D } }
#end

#macro IC_BIntersection5(_ICSG_fn_A, _ICSG_ob_A, _ICSG_fn_B, _ICSG_ob_B, _ICSG_fn_C, _ICSG_ob_C, _ICSG_fn_D, _ICSG_ob_D, _ICSG_fn_E, _ICSG_ob_E)
  IC_Intersection5(function(x, y, z){ _ICSG_fn_A(x, y, z) },     // intersection between 5 objects
                   function(x, y, z){ _ICSG_fn_B(x, y, z) },
                   function(x, y, z){ _ICSG_fn_C(x, y, z) },
                   function(x, y, z){ _ICSG_fn_D(x, y, z) },
                   function(x, y, z){ _ICSG_fn_E(x, y, z) }) ,
  intersection { object{ _ICSG_ob_A } object{ _ICSG_ob_B } object{ _ICSG_ob_C } object{ _ICSG_ob_D } object{ _ICSG_ob_E } }
#end

#macro IC_BIntersection_Array( _ICSG_Array , _ICSG_Common_Container )
  IC_Intersection_Array( _ICSG_Array ) , _ICSG_Common_Container
#end


#macro IC_BDifference2(_ICSG_fn_A, _ICSG_ob_A, _ICSG_fn_B, _ICSG_ob_B)
  IC_Difference2(function(x, y, z){ _ICSG_fn_A(x, y, z) },       // difference between 2 objects
                 function(x, y, z){ _ICSG_fn_B(x, y, z) }) ,
  difference { object{ _ICSG_ob_A } object{ _ICSG_ob_B } }
#end

#macro IC_BDifference3(_ICSG_fn_A, _ICSG_ob_A, _ICSG_fn_B, _ICSG_ob_B, _ICSG_fn_C, _ICSG_ob_C)
  IC_Difference3(function(x, y, z){ _ICSG_fn_A(x, y, z) },       // difference between 3 objects
                 function(x, y, z){ _ICSG_fn_B(x, y, z) },
                 function(x, y, z){ _ICSG_fn_C(x, y, z) }) ,
  difference { object{ _ICSG_ob_A } object{ _ICSG_ob_B } object{ _ICSG_ob_C } }
#end

#macro IC_BDifference4(_ICSG_fn_A, _ICSG_ob_A, _ICSG_fn_B, _ICSG_ob_B, _ICSG_fn_C, _ICSG_ob_C, _ICSG_fn_D, _ICSG_ob_D)
  IC_Difference4(function(x, y, z){ _ICSG_fn_A(x, y, z) },       // difference between 4 objects
                 function(x, y, z){ _ICSG_fn_B(x, y, z) },
                 function(x, y, z){ _ICSG_fn_C(x, y, z) },
                 function(x, y, z){ _ICSG_fn_D(x, y, z) }) ,
  difference { object{ _ICSG_ob_A } object{ _ICSG_ob_B } object{ _ICSG_ob_C } object{ _ICSG_ob_D } }
#end

#macro IC_BDifference5(_ICSG_fn_A, _ICSG_ob_A, _ICSG_fn_B, _ICSG_ob_B, _ICSG_fn_C, _ICSG_ob_C, _ICSG_fn_D, _ICSG_ob_D, _ICSG_fn_E, _ICSG_ob_E)
  IC_Difference5(function(x, y, z){ _ICSG_fn_A(x, y, z) },       // difference between 5 objects
                 function(x, y, z){ _ICSG_fn_B(x, y, z) },
                 function(x, y, z){ _ICSG_fn_C(x, y, z) },
                 function(x, y, z){ _ICSG_fn_D(x, y, z) },
                 function(x, y, z){ _ICSG_fn_E(x, y, z) }) ,
  difference { object{ _ICSG_ob_A } object{ _ICSG_ob_B } object{ _ICSG_ob_C } object{ _ICSG_ob_D } object{ _ICSG_ob_E } }
#end

#macro IC_BDifference_Array( _ICSG_Array , _ICSG_Common_Container )
  IC_Difference_Array( _ICSG_Array ) , _ICSG_Common_Container
#end


#macro IC_BInverse(_ICSG_Fn, _ICSG_Ob)
  IC_Inverse(function(x, y, z){ _ICSG_Fn(x, y, z) }),
  object{ _ICSG_Ob inverse }
#end

//-------------------------------------------------------------
// ----   Shape macros   --------------------------------------
//-------------------------------------------------------------

#macro IC_BPlane (_ICSG_Direction, _ICSG_Distance)
  IC_Plane (_ICSG_Direction, _ICSG_Distance) ,
  plane { _ICSG_Direction, _ICSG_Distance }
#end

#macro IC_BSphere (_ICSG_Center, _ICSG_Radius)
  IC_Sphere (_ICSG_Center, _ICSG_Radius) ,
  sphere { _ICSG_Center, _ICSG_Radius }
#end

#macro IC_BBox (_ICSG_Start, _ICSG_End)
  IC_Box (_ICSG_Start, _ICSG_End) ,
  box { _ICSG_Start, _ICSG_End }
#end

#macro IC_BRound_Box (_ICSG_Start, _ICSG_End, _ICSG_Radius)
  IC_Round_Box (_ICSG_Start, _ICSG_End, _ICSG_Radius) ,
  Round_Box(_ICSG_Start, _ICSG_End, _ICSG_Radius, true)
#end

#macro IC_BTorus (_ICSG_MaR, _ICSG_MiR)
  IC_Torus (_ICSG_MaR, _ICSG_MiR) ,
  torus { _ICSG_MaR, _ICSG_MiR }
#end

#macro IC_BCylinder (_ICSG_Start, _ICSG_End, _ICSG_Radius)
  IC_Cylinder (_ICSG_Start, _ICSG_End, _ICSG_Radius) ,
  cylinder { _ICSG_Start, _ICSG_End, _ICSG_Radius }
#end

#macro IC_BCylinder_Hole (_ICSG_Start, _ICSG_End, _ICSG_Radius, _ICSG_Hole)
  IC_Cylinder_Hole (_ICSG_Start, _ICSG_End, _ICSG_Radius, _ICSG_Hole) ,
  difference {
    cylinder { _ICSG_Start, _ICSG_End, _ICSG_Radius }
    cylinder { _ICSG_Start - (_ICSG_End-_ICSG_Start)*0.01,
               _ICSG_End + (_ICSG_End-_ICSG_Start)*0.01, _ICSG_Hole }
  }
#end

#macro IC_BCone (_ICSG_Start, _ICSG_Radius1, _ICSG_End, _ICSG_Radius2)
  IC_Cone (_ICSG_Start, _ICSG_Radius1, _ICSG_End, _ICSG_Radius2) ,
  cone { _ICSG_Start, _ICSG_Radius1, _ICSG_End, _ICSG_Radius2 }
#end


#macro IC_BSuperellipsoid (_ICSG_EW, _ICSG_NS)
  IC_Superellipsoid (_ICSG_EW, _ICSG_NS) ,
  superellipsoid { _ICSG_EW, _ICSG_NS }
#end


#macro IC_BSor(_ICSG_Array,_ICSG_Open)
  IC_Sor(_ICSG_Array,_ICSG_Open),
  sor{
    #local N=dimension_size(_ICSG_Array,1);
    N
    #local n=0;
    #while(n<N)
      _ICSG_Array[n]
      #local n=n+1;
    #end
  }
#end

#macro IC_BTriangle (_ICSG_V1,_ICSG_V2,_ICSG_V3,_ICSG_Thickness)
  IC_Triangle (_ICSG_V1,_ICSG_V2,_ICSG_V3,_ICSG_Thickness) ,
  triangle { _ICSG_V1,_ICSG_V2,_ICSG_V3 }
#end

//-------------------------------------------------------------
// ----   Transform macros   ----------------------------------
//-------------------------------------------------------------

#macro IC_BTransform (_ICSG_Fn, _ICSG_Ob, _ICSG_Trans)
  IC_Transform (function(x, y, z){ _ICSG_Fn(x, y, z) }, _ICSG_Trans) ,
  object { _ICSG_Ob transform { _ICSG_Trans } }
#end

#macro IC_BTranslate (_ICSG_Fn, _ICSG_Ob, _ICSG_Vect)
  IC_Translate (function(x, y, z){ _ICSG_Fn(x, y, z) }, _ICSG_Vect) ,
  object { _ICSG_Ob translate _ICSG_Vect }
#end

#macro IC_BScale (_ICSG_Fn, _ICSG_Ob, _ICSG_Vect)
  IC_Scale (function(x, y, z){ _ICSG_Fn(x, y, z) }, _ICSG_Vect) ,
  object { _ICSG_Ob scale _ICSG_Vect }
#end

#macro IC_BScaleC (_ICSG_Fn, _ICSG_Ob, _ICSG_Vect)
  IC_ScaleC (function(x, y, z){ _ICSG_Fn(x, y, z) }, _ICSG_Vect) ,
  object { _ICSG_Ob scale _ICSG_Vect }
#end

#macro IC_BMatrix (_ICSG_Fn, _ICSG_Ob, _ICSG_Mtrx)       // not equivalent to the matrix transform!
  IC_Matrix (function(x, y, z){ _ICSG_Fn(x, y, z) }, _ICSG_Mtrx) ,
  object { _ICSG_Ob
    transform {
      matrix <
        _ICSG_Mtrx[0][0] _ICSG_Mtrx[0][1] _ICSG_Mtrx[0][2]
        _ICSG_Mtrx[1][0] _ICSG_Mtrx[1][1] _ICSG_Mtrx[1][2]
        _ICSG_Mtrx[2][0] _ICSG_Mtrx[2][1] _ICSG_Mtrx[2][2]
        0          0          0
      >
      inverse
    }
  }
#end

#macro IC_BRotateR (_ICSG_Fn, _ICSG_Ob, _ICSG_Vect)      // Rotate Radians
  #local Vect=_ICSG_Vect+<0,0,0>;
  IC_RotateR (function(x, y, z){ _ICSG_Fn(x, y, z) }, Vect),
  object { _ICSG_Ob rotate <degrees(Vect.x),degrees(Vect.y),degrees(Vect.z)> }
#end

#macro IC_BRotate (_ICSG_Fn, _ICSG_Ob, _ICSG_Vect)       // Rotate Degrees
  IC_Rotate (function(x, y, z){ _ICSG_Fn(x, y, z) }, _ICSG_Vect),
  object { _ICSG_Ob rotate _ICSG_Vect }
#end

// Special transforms using macros from 'transforms.inc'
// by Tor Olav Kristensen

#macro IC_BReorient(Fn, Ob, _ICSG_vAxis1, _ICSG_vAxis2)
  IC_Reorient(function(x, y, z){ _ICSG_Fn(x, y, z) }, _ICSG_vAxis1, _ICSG_vAxis2),
  object { _ICSG_Ob Reorient_Trans(_ICSG_vAxis1, _ICSG_vAxis2) }
#end // macro IC_BReorient


#macro IC_BAxisRotate(_ICSG_Fn, _ICSG_Ob, _ICSG_vAxis, _ICSG_Angle)
  IC_Reorient(function(x, y, z){ _ICSG_Fn(x, y, z) }, _ICSG_vAxis, _ICSG_Angle),
  object { _ICSG_Ob Reorient_Trans(_ICSG_vAxis, _ICSG_Angle) }
#end // macro IC_BAxisRotate


//-------------------------------------------------------------
// ----   Container extraction macros   -----------------------
//-------------------------------------------------------------

#macro IC_Extents(_ICSG_Fn, _ICSG_Ob)              // Extract dimensions
  #declare IC_Min = min_extent( _ICSG_Ob );
  #declare IC_Max = max_extent( _ICSG_Ob );
  function(x, y, z) { _ICSG_Fn(x,y,z) }
#end

#macro IC_Container(_ICSG_Fn, _ICSG_Ob)            // Extract container object
  box { min_extent(_ICSG_Ob), max_extent(_ICSG_Ob) }
#end

//-------------------------------------------------------------
// ----   Function/Object extraction macros   -----------------
//-------------------------------------------------------------

#macro IC_Function(_ICSG_Fn, _ICSG_Ob)             // Extract Function
  function(x, y, z) { _ICSG_Fn(x,y,z) }
#end

#macro IC_Object(_ICSG_Fn, _ICSG_Ob)               // Extract Object
  object { _ICSG_Ob }
#end

//-------------------------------------------------------------


#version iso_BCSG_Inc_Temp;
#end
