// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// %                                                                   %
// %   IsoCSG Library - version 0.6                                    %
// %                                                                   %
// %   iso_chars.inc - ISO-Characters for POV-Ray Version 3.5          %
// %                   translation of 'chars.inc' to IsoCSG            %
// %                                                                   %
// %   developed March 2002 by ABX <abx@abx.art.pl>                    %
// %                                                                   %
// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// %                                                                   %
// %   Feel free to use this file for your povray work, I encourage    %
// %   you to contact me if you have ideas for improvements.           %
// %                                                                   %
// %   This is an experimental version so syntax and used methods      %
// %   are subject to changes.                                         %
// %                                                                   %
// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

#ifdef(iso_Chars_Inc_Temp)
// do nothing
#else
#declare iso_Chars_Inc_Temp=version;


#ifdef(View_POV_Include_Stack)
#   debug "including iso_chars.inc\n"
#end

/*
	      Persistence of Vision Raytracer Version 3.1

		   ISO-Characters for POV-Ray Version 3.5
		     Original by Ken Maeno 1992-93
		  Revised and extended by Chris Young
	    Revised for internal web removal by John Andersen
	    Rewritten as iso_csg by Wlodzimierz ABX Skiba

 This file includes 26 upper-case letter and other characters defined
 as functions (via macros). IC_Text() macro added for strings.
 The size of all characters is 4 * 5 * 1. The center of the
 bottom side of a character face is set to the origin, so please
 translate a character appropriately before rotating it about
 the x or z axes. The origin of strings from IC_Text() is different.

	Usage:

	isosurface{
	  IC_Char_A()
	  contained_by{<-2,0,0><2,5,1>}
	  pigment{ color Red }
	}

  or

	isosurface{
	  IC_Char("A")
	  contained_by{<-2,0,0><2,5,1>}
	  pigment{ color Red }
	}

  or

	isosurface{
	  IC_Text("POV-Ray", 0.5, 0.1)
	  contained_by{box{<0,0,0><34,5,1>}}
	  pigment{ color Red }
	}

*/

#ifndef(iso_CSG_Inc_Temp)
  #include "iso_csg.inc"
#end

#macro IC_Char_A ()
  #local T=IC_Thickness();
  #local f_M2 = IC_Merge2 (
    IC_Intersection2 (
      IC_Box ( <-2,0,0> , <2,5,T> ),
      IC_Transform( IC_Box ( <-0.5,-6,0>,<0.5,0,T> ) , transform{ rotate z*16.699 translate y*5 } )
    ),
    IC_Intersection2 (
      IC_Box ( <-2,1,0> , <2,2,T> ),
      IC_Transform( IC_Plane ( x , 0.5 ) , transform{ rotate z*16.699 translate y*5 } )
    )
  );
  function{ f_M2(abs(x),y,z) }
#end

#macro IC_Char_B ()
  #local T=IC_Thickness();
  #local f_CH = IC_Cylinder_Hole ( <0.5,1,0> , <0.5,1,T> , 1.5 , .5 );
  #local f_M2 = IC_Merge2 (
    IC_Box ( <-2,-1.5, 0> , <-1,1.5, T> ),
    IC_Box ( <-2, 0.5, 0> , < 2,1.5, T> )
  );
  function { select( x-.5 , f_M2(x,abs(abs(y-2.5)-1),z), f_CH(x,abs(y-2.5),z))}
#end

#macro IC_Char_C ()
  #local T=IC_Thickness();
  #local f_J = IC_Char_J ();
  function{ f_J(-x,2.5-abs(y-2.5),z)}
#end

#macro IC_Char_D ()
  #local T=IC_Thickness();
  #local f_M2a = IC_Merge2 (
    IC_Cylinder_Hole ( <-0.5,2.5,0> , <-0.5,2.5,T> , 2.5 , 1.5 ),
    IC_Box ( <-2,0,0>,<-1,5,T> )
  );
  #local f_M2b = IC_Merge2 (
    IC_Box ( <-2, 1.5,0>,< 2,2.5,T> ),
    IC_Box ( <-2,-2.5,0>,<-1,2.5,T> )
  );
  function { select( x+.5 , f_M2b(x,abs(y-2.5),z) , f_M2a(x,y,z) ) }
#end

#macro IC_Char_E ()
  #local T=IC_Thickness();
  #local f_E=IC_Merge3 (
    IC_Box ( <-2,-2.5,0>,<-1  ,2.5,T> ),
    IC_Box ( <-2,-0.5,0>,< 1.5,0.5,T> ),
    IC_Box ( <-2, 1.5,0>,< 2  ,2.5,T> )
  );
  function{f_E(x,abs(y-2.5),z)}
#end

#macro IC_Char_F ()
  #local T=IC_Thickness();
  IC_Merge3 (
    IC_Box ( <-2,0,0>,<-1  ,5,T> ),
    IC_Box ( <-2,2,0>,< 1.5,3,T> ),
    IC_Box ( <-2,4,0>,< 2  ,5,T> )
  )
#end

#macro IC_Char_G ()
  #local T=IC_Thickness();
  IC_Merge2 (
    IC_Char_C (),
    IC_Box ( < 0,1.5,0>,<2,2.3,T> )
  )
#end

#macro IC_Char_H ()
  #local T=IC_Thickness();
  #local f_H=IC_Merge2 (
    IC_Box ( < 1,0,0> , < 2,5,T> ),
    IC_Box ( <-2,2,0> , < 2,3,T> )
  )
  function{f_H(abs(x),y,z)}
#end

#macro IC_Char_I ()
  #local T=IC_Thickness();
  IC_Box (  <-0.5,0,0> , <0.5,5,T> )
#end

#macro IC_Char_J ()
  #local T=IC_Thickness();
  #local f_M2 = IC_Merge2 (
    IC_Box ( < 1,0,0> , < 2,5,T> ),
    IC_Box ( <-2,0,0> , <-1,2,T> )
  );
  #local f_CH = IC_Cylinder_Hole ( <0,2,0> , <0,2,T> , 2 , 1 );
  #local f_I2 = IC_Intersection2 (
    function{ f_CH(x,y,z) },
    IC_Plane( y , 2 )
  );
  function { select( y-2 , select( x , f_I2(x,y,z) , f_CH(x,y,z) ) , f_M2(x,y,z) ) }
#end

#macro IC_Char_K ()
  #local T=IC_Thickness();
  #local f_M2 = IC_Merge2 (
    IC_Intersection2 (
      IC_Transform ( IC_Box ( <0,-5,0>,<0.9,2,T> ) , transform{ rotate -z*45 translate <0.7272,2.5,0> } ),
      IC_Box ( <-2,-2.5,0>,<2,2.5,T> )
    ),
    IC_Box ( <-2,-2.5,0>,<-1,2.5,T> )
  );
  #local f_B = IC_Box ( <-2,0,0>,<-1,5,T> );
  function{ select(x+1.5,f_B(x,y,z),f_M2(x,abs(y-2.5),z)) }
#end

#macro IC_Char_L ()
  #local T=IC_Thickness();
  IC_Merge2 (
    IC_Box ( <-2,0,0> , <-1,5,T> ),
    IC_Box ( <-2,0,0> , < 2,1,T> )
  )
#end

#macro IC_Char_M ()
  #local T=IC_Thickness();
  #local f_M2 = IC_Merge2 (
    IC_Intersection2 (
      IC_Transform ( IC_Box ( <-0.5,-1,0> , <0.5,5,T> ) , transform{ rotate -z*26.5651 translate y*2 } ),
      IC_Box ( <-2,2,0> , <2,5,T> )
    ),
    IC_Box ( < 1,0,0> , < 2,5,T> )
  );
  #local f_B = IC_Box ( < 1,0,0> , < 2,5,T> );
  #local f_M = function{ select(x-1.5,f_M2(x,y,z),f_B(x,y,z)) }
  function{ f_M(abs(x),y,z) }
#end

#macro IC_Char_N ()
  #local T=IC_Thickness();
  #local f_M2 = IC_Merge2 (
    IC_Intersection2 (
      IC_Transform ( IC_Box ( <0,-5,0> , <1,5,T> ) , transform{ rotate z*32.5031 translate x } ),
      IC_Box ( <-2,0,0> , <2,5,T> )
    ),
    IC_Box ( < 1,0,0> , < 2,5,T> )
  )
  #local f_B = IC_Box ( < 1,0,0> , < 2,5,T> );
  #local f_N = function{ select(x-1.5,f_M2(x,y,z),f_B(x,y,z)) }
  function { f_N(abs(x),select(x,5-y,y),z)}
#end

#macro IC_Char_O ()
  #local T=IC_Thickness();
  #local f_CH = IC_Cylinder_Hole ( <0,2,0> , <0,2,T> , 2 , 1 );
  function{ f_CH(x,min(y,max(y-1,2)),z)}
#end

#macro IC_Char_P ()
  #local T=IC_Thickness();
  #local f_CH = IC_Cylinder_Hole ( <.5,0,0> , <.5,0,T> , 1.5 , 0.5 );
  #local f_B = IC_Box ( <-2, 0, 0>, <-1, 5, T> );
  #local f_M2 = IC_Merge2 (
    function { f_CH ( max(x,.5) , abs(y-3.5) , z ) },
    function{ f_B(x,y,z) }
  );
  function { select( x+1.5 , f_B(x,y,z) , f_M2(x,y,z) ) }
#end

#macro IC_Char_Q ()
  #local T=IC_Thickness();
  IC_Merge2 (
    IC_Char_O(),
    IC_Transform( IC_Box ( <0,0,0> , <1,2.2,T> ) , transform{ rotate z*45 translate x*1.29289 } )
  )
#end

#macro IC_Char_R ()
  #local T=IC_Thickness();
  IC_Merge2 (
    IC_Char_P (),
    IC_Intersection2 (
      IC_Transform ( IC_Box ( <0,-2,0> , <1,5,T> ) transform{ rotate z*36.8699 translate x} ),
      IC_Box ( <-1,0,0> , <2,3,T> )
    )
  )
#end

#macro IC_Char_S ()
  #local T=IC_Thickness();
  #local f_I2 = IC_Intersection2 (
    IC_Cylinder_Hole ( <.5,3.5,0> , <.5,3.5,T> , 1.5 , 0.5 ),
    IC_Plane ( -y , -3.5 )
  );
  #local f_M2 = IC_Merge2 (
    IC_Cylinder_Hole ( <.5,1.5,0> , <.5,1.5,T> , 1.5 , 0.5 ),
    IC_Box( <1,3.5,0> , <2,5,T> )
  );
  #local f_S = function{ select( y-3.5 , f_M2(x,y,z) , f_I2(x,y,z) ) };
  function{ f_S(max(abs(x),.5),select(x,5-y,y),z) }
#end

#macro IC_Char_T ()
  #local T=IC_Thickness();
  IC_Merge2 (
    IC_Box ( <-0.5,0,0> , <0.5,5,T> ),
    IC_Box ( <-2  ,4,0> , <2  ,5,T> )
  )
#end

#macro IC_Char_U ()
  #local T=IC_Thickness();
  #local f_B = IC_Box ( < 1,0,0> , < 2,5,T> );
  #local f_CH=IC_Cylinder_Hole ( <0,2,0> , <0,2,T> , 2 , 1 );
  function { select( y-2 , f_CH(x,y,z) , f_B(abs(x),y,z) ) }
#end

#macro IC_Char_V ()
  #local T=IC_Thickness();
  #local f_I2 = IC_Intersection2 (
    IC_Box ( <-2,0,0> , <2,5,T> ),
    IC_Rotate ( IC_Box ( <-0.5,-1,0> , <0.5,6,T> ) , -z*16.699 )
  );
  function{ f_I2(abs(x),y,z) }
#end

#macro IC_Char_W ()
  #local T=IC_Thickness();
  #local f_M2 = IC_Merge2 (
    IC_Intersection2 (
      IC_Transform ( IC_Box ( <-0.5,-5,0> , <0.5,1,T> ) , transform { rotate  z*26.5651 translate 3*y } ),
      IC_Box ( <-1,0,0> , <2,3,T> )
    ),
    IC_Box ( < 1,0,0> , < 2,5,T> )
  );
  #local f_B = IC_Box ( < 1,0,0> , < 2,5,T> );
  #local f_W = function{ select(x-1.5,f_M2(x,y,z),f_B(x,y,z)) }
  function{ f_W(abs(x),y,z) }
#end

#macro IC_Char_X ()
  #local T=IC_Thickness();
  #local f_M2 = IC_Intersection2 (
    IC_Box ( <-2,-2.5,0> , <2,2.5,T> ),
    IC_Transform ( IC_Box ( <-0.5,-3.5,0> , <0.5,3.5,T> ) , transform { rotate -z*30.9 } )
  )
  function{ f_M2(abs(x),abs(y-2.5),z) }
#end

#macro IC_Char_Y ()
  #local T=IC_Thickness();
  #local f_M2 = IC_Merge2 (
    IC_Intersection2 (
      IC_Box ( <-2,2,0> , <2,5,T> ),
      IC_Transform( IC_Box ( <-0.5,-3.5,0> , <0.5,3.5,T> ) , transform { rotate -z*30.9 translate 2.5*y } )
    ),
    IC_Box( <-0.5,0,0> , <0.5,3,T> )
  );
  function{ f_M2(abs(x),y,z) }
#end

#macro IC_Char_Z ()
  #local T=IC_Thickness();
  #local f_M2 = IC_Merge2 (
    IC_Intersection2 (
      IC_Transform( IC_Box ( <0,0,0>,<1,7,T>  ) , transform { rotate z*-29.6749 translate -2*x translate -2.5*y } ),
      IC_Box ( <-2,-2.5,0> , <2,2.5,T> )
    ),
    IC_Intersection2 (
      IC_Box ( <-2,1.5,0> , <2,2.5,T> ),
      IC_Transform( IC_Plane( x , 1 ) , transform { rotate z*-29.6749 translate -2*x translate -2.5*y } ),
    )
  );
  function { f_M2(select(y-2.5,-x,x),abs(y-2.5),z) }
#end

#macro IC_Char_Dash ()
  #local T=IC_Thickness();
  IC_Box ( <-2,2,0> , <2,3,T> )
#end

#macro IC_Char_Plus ()
  #local T=IC_Thickness();
  IC_Merge2 (
    IC_Box ( <-2  ,2  ,0> , <2  ,3  ,T> ),
    IC_Box ( <-0.5,0.5,0> , <0.5,4.5,T> )
  )
#end

#macro IC_Char_0 ()
  IC_Char_O ()
#end

#macro IC_Char_1 ()
  #local T=IC_Thickness();
  IC_Merge3 (
    IC_Char_I(),
    IC_Intersection2 (
      IC_Transform( IC_Box ( <0,-1.25,0> , <1,2,T> ) , transform { rotate -z*45 translate <-0.5,5,0> } ),
      IC_Box( <-2,0,0> , <.5,5,T> )
    ),
    IC_Box ( <-1,0,0> , <1,1,T> )
  )
#end

#macro IC_Char_2 ()
  #local T=IC_Thickness();
  #local f_CHa = IC_Cylinder_Hole ( <0.5,3.5,0> , <0.5,3.5,T> , 1.5 , 0.5 );
  #local f_CHb = IC_Cylinder_Hole ( <0  ,0  ,0> , <0  ,0  ,T> , 1.5 , 0.5 );
  #local f_M3 = IC_Merge3 (
    IC_Box( <-2,3.5,0> , <-1,5,T> ),
    IC_Box( <-2,0  ,0> , < 2,1,T> ),
    IC_Intersection2 (
      IC_Box( <-2,0  ,0> , < 2,5,T> ),
      IC_Merge2 (
        IC_Transform (
          function {
            select(
              y,
              abs(y)+.5,
              f_CHb(min(x,0),max(y,0),z)
            )
          } ,
          transform { rotate -z*(90+54) translate <0.5,3.5,0> }
        ),
        IC_Box( <-.5,4,0> , <.5,5,T> )
      )
    )
  );
  #local f_I2 = IC_Intersection2 (
    IC_Cylinder_Hole ( <-.5,3.5,0> , <-.5,3.5,T> , 1.5 , 0.5 ),
    IC_Plane ( -y , -3.5 )
  );
  function {
    select(
      y-3.5,
      f_M3(x,y,z),
      select(
        x,
        f_I2(min(x,-.5),y,z),
        f_CHa(max(x,.5),y,z)
      )
    )
  }
#end

#macro IC_Char_3 ()
  #local T=IC_Thickness();
  #local f_B = IC_Box ( <1,-.5,0> , <3,.5,T> );
  #local f_I2 = IC_Intersection2 (
    IC_Cylinder_Hole ( <1,1,0> , <1,1,T> , .5 , 1.5 ),
    IC_Plane ( -y , -1 )
  );
  #local f_CH = IC_Cylinder_Hole ( <2,1,0> , <2,1,T> , .5 , 1.5 );
  #local f_3 = function {
    select(
      x-1 ,
      select(
        y-1 ,
        f_B(max(x,y),min(x,y),z) ,
        f_I2(x,y,z)
      ) ,
      select(
        y-1 ,
        select(
          x-2 ,
          f_B(x,y,z) ,
          f_CH(x,y,z)
        ),
        f_CH(max(x,2),y,z)
      )
    )
  };
  function { f_3( x+1.5 , abs(y-2.5) , z ) }
#end

#macro IC_Char_4 ()
  #local T=IC_Thickness();
  IC_Merge3 (
    IC_Box( < 0,0,0> , <1,5,T> ),
    IC_Box( <-2,1,0> , <2,2,T> ),
    IC_Intersection2 (
      IC_Transform( IC_Box( <-2,-1,0> , <5,0,T> ) , transform { rotate z*56.31 translate <-2,2,0> } ),
      IC_Box( <-2,1,0> , <1,5,T> )
    )
  )
#end

#macro IC_Char_5 ()
  #local T=IC_Thickness();
  #local f_M2 = IC_Merge2 (
    IC_Cylinder_Hole ( <.5,1.5,0> , <.5,1.5,T> , 1.5 , 0.5 ),
    IC_Box ( <-2,4,0> , <2,5,T> )
  )
  #local f_I2 = IC_Intersection2 (
    IC_Cylinder_Hole ( <-.5,1.5,0> , <-.5,1.5,T> , 1.5 , 0.5 ),
    IC_Plane ( y , 1.5 )
  )
  #local f_M4 = IC_Merge4 (
    IC_Box (  <-2,4,0> , < 2,5  ,T> ),
    IC_Box (  <-2,2,0> , <-1,5  ,T> ),
    IC_Box (  <-2,2,0> , < 2,3  ,T> ),
    IC_Box (  <-2,0,0> , <-1,1.5,T> )
  )
  function {
    select(
      x,
      select(
        y-1.5,
        f_I2(min(x,-.5),y,z),
        f_M4(min(x,-.5),y,z)
      ),
      f_M2(max(x,.5),y,z)
    )
  }
#end

#macro IC_Char_6 ()
  #local T=IC_Thickness();
  #local f_M2a = IC_Merge2 (
    IC_Box ( <1,3.5,0> , <2,5,T> ),
    IC_Cylinder_Hole ( <.5,1.5,0> , <.5,1.5,T> , 1.5 , 0.5 )
  );
  #local f_I2 = IC_Intersection2 (
    IC_Cylinder_Hole ( <.5,3.5,0> , <.5,3.5,T> , 1.5 , 0.5 ),
    IC_Plane ( -y , -3.5 )
  );
  #local f_CHa = IC_Cylinder_Hole ( <-.5,3.5,0> , <-.5,3.5,T> , 1.5 , 0.5 )
  #local f_M2b = IC_Merge2 (
    IC_Cylinder_Hole ( <-.5,1.5,0> , <-.5,1.5,T> , 1.5 , 0.5 ),
    IC_Box ( <-2,0,0> , <-1,5,T> )
  );
  #local f_CHb = IC_Cylinder_Hole ( <-.5,1.5,0> , <-.5,1.5,T> , 1.5 , 0.5 );
  function {
    select(
      x,
      select(
        y-3.5,
        select(
          y-1.5,
          f_CHb(min(x,-.5),y,z),
          f_M2b(min(x,-.5),y,z)
        ),
        f_CHa(min(x,-.5),y,z)
      ),
      select(
        y-3.5,
        f_M2a(max(x,.5),y,z),
        f_I2(max(x,.5),y,z)
      )
    )
  }
#end

#macro IC_Char_7 ()
  #local T=IC_Thickness();
  IC_Merge2 (
    IC_Box ( <-2,4,0> , <2,5,T> ),
    IC_Intersection2 (
      IC_Transform ( IC_Box ( <-1,-1,0> , <0,6,T> ) , transform { rotate -z*20.556 translate x/2 } ),
      IC_Box ( <-0.5,0,0> , <2,5,T> )
    )
  )
#end

#macro IC_Char_8 ()
  #local T=IC_Thickness();
  #local f_CH = IC_Cylinder_Hole ( <0,1,0> , <0,1,T> , 1.5 , .5 );
  function { f_CH( min(x+.5,max(x-.5,0)) , abs(y-2.5) , z ) }
#end

#macro IC_Char_9 ()
  #local T=IC_Thickness();
  #local f_M2a = IC_Merge2 (
    IC_Box ( <-2,0,0> , <-1,1.5,T> ),
    IC_Cylinder_Hole ( <-.5,3.5,0> , <-.5,3.5,T> , 1.5 , 0.5 )
  );
  #local f_I2 = IC_Intersection2 (
    IC_Cylinder_Hole ( <-.5,1.5,0> , <-.5,1.5,T> , 1.5 , 0.5 ),
    IC_Plane ( y , 1.5 )
  );
  #local f_CHa = IC_Cylinder_Hole ( <.5,1.5,0> , <.5,1.5,T> , 1.5 , 0.5 )
  #local f_M2b = IC_Merge2 (
    IC_Cylinder_Hole ( <.5,3.5,0> , <.5,3.5,T> , 1.5 , 0.5 ),
    IC_Box ( <1,0,0> , <2,5,T> )
  );
  #local f_CHb = IC_Cylinder_Hole ( <.5,3.5,0> , <.5,3.5,T> , 1.5 , 0.5 );
  function {
    select(
      x,
      select(
        y-1.5,
        f_I2(min(x,-.5),y,z),
        f_M2a(min(x,-.5),y,z)
      ),
      select(
        y-1.5,
        f_CHa(max(x,.5),y,z),
        select(
          y-3.5,
          f_M2b(max(x,.5),y,z),
          f_CHb(max(x,.5),y,z)
        )
      )
    )
  }
#end

#macro IC_Char_ExclPt()
  #local T = IC_Thickness();
  #local f_Ca = IC_Cylinder ( <0,0,0> , <0,0,T> , 0.5 );
  #local f_Cb = IC_Cylinder ( <0,0.5,0> , <0,0.5,T> , 0.5 );
  #local f_M2 = IC_Merge2 (
    IC_Transform(
      function{ f_Ca(x,max(y,0),z) },
      transform { rotate -z*9.5 translate y*4.5 }
    ),
    IC_Cylinder ( <0,0.5,0> , <0,0.5,T> , 0.5 )
  );
  function{ select( y , f_Cb(x,y,z) , f_M2(abs(x),y,z) ) }
#end

#macro IC_Char_AtSign ()
  #local T=IC_Thickness();
  #local f_M2 = IC_Merge2 (
    IC_Cylinder_Hole ( <0,2.5,0> , <0,2.5,T> , 2 , 1.5 ),
    IC_Cylinder_Hole ( <0,2.5,0> , <0,2.5,T> , 1 , 0.5 )
  );
  #local f_M3 = IC_Merge3 (
    IC_Intersection2 (
      IC_Cylinder_Hole ( <0,2.5,0> , <0,2.5,T> , 2 , 1.5 ),
      IC_Plane ( y , 1.25 )
    ),
    IC_Cylinder_Hole ( <0,2.5,0> , <0,2.5,T> , 1 , 0.5 ),
    IC_Cylinder_Hole ( <1.25,2.5,0> , <1.25,2.5,T> , 0.75 , 0.25 )
  );
  function{
    select(
      y-2.5 ,
      select(
        x,
        f_M2(x,y,z),
        f_M3(x,y,z)
      ),
      f_M2(x,y,z)
    )
  }
#end

#macro IC_Char_Num ()
  #local T=IC_Thickness();
  IC_Merge4 (
    IC_Transform( IC_Box ( <-0.5,-2,0> , <0.5,2,T> ) , transform { rotate -10*z translate <-1,2.5,0> } ),
    IC_Transform( IC_Box ( <-0.5,-2,0> , <0.5,2,T> ) , transform { rotate -10*z translate < 1,2.5,0> } ),
    IC_Box ( <-1.5,3,0> , <2  ,4,T> ),
    IC_Box ( <-2  ,1,0> , <1.5,2,T> )
  )
#end

#macro IC_Char_Dol ()
  #local T=IC_Thickness();
  #local f_M2 = IC_Merge2 (
    IC_Cylinder_Hole ( <0.75,1.75,0> , <0.75,1.75,T> , 1.25 , 0.25 ),
    IC_Box ( <-0.75,3.5,0> , <2,4.5,T> )
  );
  IC_Merge2 (
    function{ f_M2(max(abs(x),.75),select(x,5-y,y),z) },
    IC_Box ( <-0.5 ,0  ,0> , <0.5 ,5  ,T> )
  )
#end

#macro IC_Char_Perc ()
  #local T=IC_Thickness();
  IC_Merge3 (
    IC_Cylinder_Hole ( < 1,1,0> , < 1,1,T> , 1 , .25 ),
    IC_Cylinder_Hole ( <-1,4,0> , <-1,4,T> , 1 , .25 ),
    IC_Transform ( IC_Box ( <-0.25,-2.8,0> , <0.25,2.8,T> ) , transform { rotate -33*z translate 2.5*y } )
  )
#end

#macro IC_Char_Hat ()
  #local T=IC_Thickness();
  #local f_I2 = IC_Intersection2 (
    IC_Transform ( IC_Box ( <-1,0,0> , <0,3,T> ) , transform { rotate 33*z translate <2,1.5,0> } ),
    IC_Box ( <-2,1.5,0> , <2,3.75,T> )
  );
  function{ f_I2(abs(x),y,z) }
#end

#macro IC_Char_Amps ()
  #local T=IC_Thickness();
  #local f_B  = IC_Box ( <0,.5,0> , <2,1.25,T> );
  #local f_I2 = IC_Intersection2 (
    IC_Cylinder_Hole ( <2,1.75,0> , <2,1.75,T> , 1.25 , .5  ),
    IC_Plane ( x , 2 )
  );
  IC_Merge3 (
    IC_Cylinder_Hole ( <-0.25,3.75,0> , <-0.25,3.75,T> , 1.25 , .5  ),
    IC_Cylinder_Hole ( <-0.25,1.75,0> , <-0.25,1.75,T> , 1.75 , .75 ),
    function { select ( x-2 , f_I2(x,y,z), f_B(x,abs(y-1.75),z)) }
  )
#end

#macro IC_Char_Astr ()
  #local T=IC_Thickness();
  #local f_M2=IC_Merge2 (
    IC_Transform ( IC_Box ( <-0.5,-2,0> , <0.5,2,T> ) , transform { rotate  -60*z } ),
    IC_Box ( <-0.5,-2,0>,<0.5,2,T> )
  )
  function{ f_M2(abs(x),abs(y-2.5),z) }
#end

#macro IC_Char_LPar ()
  #local T=IC_Thickness();
  IC_Intersection2 (
    IC_Cylinder_Hole ( <7,2.5,0> , <7,2.5,T> , 7.5 , 6.5 ),
    IC_Box ( <-2,0,0> , <2,5,T> )
  )
#end

#macro IC_Char_RPar ()
  #local T=IC_Thickness();
  IC_Intersection2 (
    IC_Cylinder_Hole ( <-7,2.5,0> , <-7,2.5,T> , 7.5 , 6.5 ),
    IC_Box ( <-2,0,0> , <2,5,T> )
  )
#end

#macro IC_Char_LSqu ()
  #local T=IC_Thickness();
  #local f_M2=IC_Merge2 (
    IC_Box ( <-1,-2.5,0> , <0,2.5,T> ),
    IC_Box ( <-1, 1.5,0> , <1,2.5,T> )
  );
  function{ f_M2(x,abs(y-2.5),z)}
#end

#macro IC_Char_RSqu ()
  #local T=IC_Thickness();
  #local f_M2=IC_Merge2 (
    IC_Box ( < 0,-2.5,0> , <1,2.5,T> ),
    IC_Box ( <-1, 1.5,0> , <1,2.5,T> )
  );
  function{ f_M2(x,abs(y-2.5),z)}
#end


#macro IC_Char(_ICSG_Char)
  #switch(asc(_ICSG_Char))
    #case (  33 ) IC_Char_ExclPt () #break /* ! */
    #case (  35 ) IC_Char_Num    () #break /* # */
    #case (  36 ) IC_Char_Dol    () #break /* $ */
    #case (  37 ) IC_Char_Perc   () #break /* % */
    #case (  38 ) IC_Char_Amps   () #break /* & */
    #case (  40 ) IC_Char_LPar   () #break /* ( */
    #case (  41 ) IC_Char_RPar   () #break /* ) */
    #case (  42 ) IC_Char_Astr   () #break /* * */
    #case (  43 ) IC_Char_Plus   () #break /* + */
    #case (  45 ) IC_Char_Dash   () #break /* - */
    #case (  48 ) IC_Char_0      () #break /* 0 */
    #case (  49 ) IC_Char_1      () #break /* 1 */
    #case (  50 ) IC_Char_2      () #break /* 2 */
    #case (  51 ) IC_Char_3      () #break /* 3 */
    #case (  52 ) IC_Char_4      () #break /* 4 */
    #case (  53 ) IC_Char_5      () #break /* 5 */
    #case (  54 ) IC_Char_6      () #break /* 6 */
    #case (  55 ) IC_Char_7      () #break /* 7 */
    #case (  56 ) IC_Char_8      () #break /* 8 */
    #case (  57 ) IC_Char_9      () #break /* 9 */
    #case (  64 ) IC_Char_AtSign () #break /* @ */
    #case (  65 ) IC_Char_A      () #break /* A */
    #case (  66 ) IC_Char_B      () #break /* B */
    #case (  67 ) IC_Char_C      () #break /* C */
    #case (  68 ) IC_Char_D      () #break /* D */
    #case (  69 ) IC_Char_E      () #break /* E */
    #case (  70 ) IC_Char_F      () #break /* F */
    #case (  71 ) IC_Char_G      () #break /* G */
    #case (  72 ) IC_Char_H      () #break /* H */
    #case (  73 ) IC_Char_I      () #break /* I */
    #case (  74 ) IC_Char_J      () #break /* J */
    #case (  75 ) IC_Char_K      () #break /* K */
    #case (  76 ) IC_Char_L      () #break /* L */
    #case (  77 ) IC_Char_M      () #break /* M */
    #case (  78 ) IC_Char_N      () #break /* N */
    #case (  79 ) IC_Char_O      () #break /* O */
    #case (  80 ) IC_Char_P      () #break /* P */
    #case (  81 ) IC_Char_Q      () #break /* Q */
    #case (  82 ) IC_Char_R      () #break /* R */
    #case (  83 ) IC_Char_S      () #break /* S */
    #case (  84 ) IC_Char_T      () #break /* T */
    #case (  85 ) IC_Char_U      () #break /* U */
    #case (  86 ) IC_Char_V      () #break /* V */
    #case (  87 ) IC_Char_W      () #break /* W */
    #case (  88 ) IC_Char_X      () #break /* X */
    #case (  89 ) IC_Char_Y      () #break /* Y */
    #case (  90 ) IC_Char_Z      () #break /* Z */
    #case (  91 ) IC_Char_LSqu   () #break /* [ */
    #case (  93 ) IC_Char_RSqu   () #break /* ] */
    #case (  94 ) IC_Char_Hat    () #break /* ^ */
    #case (  97 ) IC_Char_A      () #break /* a */
    #case (  98 ) IC_Char_B      () #break /* b */
    #case (  99 ) IC_Char_C      () #break /* c */
    #case ( 100 ) IC_Char_D      () #break /* d */
    #case ( 101 ) IC_Char_E      () #break /* e */
    #case ( 102 ) IC_Char_F      () #break /* f */
    #case ( 103 ) IC_Char_G      () #break /* g */
    #case ( 104 ) IC_Char_H      () #break /* h */
    #case ( 105 ) IC_Char_I      () #break /* i */
    #case ( 106 ) IC_Char_J      () #break /* j */
    #case ( 107 ) IC_Char_K      () #break /* k */
    #case ( 108 ) IC_Char_L      () #break /* l */
    #case ( 109 ) IC_Char_M      () #break /* m */
    #case ( 110 ) IC_Char_N      () #break /* n */
    #case ( 111 ) IC_Char_O      () #break /* o */
    #case ( 112 ) IC_Char_P      () #break /* p */
    #case ( 113 ) IC_Char_Q      () #break /* q */
    #case ( 114 ) IC_Char_R      () #break /* r */
    #case ( 115 ) IC_Char_S      () #break /* s */
    #case ( 116 ) IC_Char_T      () #break /* t */
    #case ( 117 ) IC_Char_U      () #break /* u */
    #case ( 118 ) IC_Char_V      () #break /* v */
    #case ( 119 ) IC_Char_W      () #break /* w */
    #case ( 120 ) IC_Char_X      () #break /* x */
    #case ( 121 ) IC_Char_Y      () #break /* y */
    #case ( 122 ) IC_Char_Z      () #break /* z */
    #else
      #local T=IC_Thickness();
      IC_Merge4 (
        IC_Box ( <-2,0,0> , < 2,1,T> ),
        IC_Box ( <-2,4,0> , < 2,5,T> ),
        IC_Box ( <-2,0,0> , <-1,5,T> ),
        IC_Box ( < 1,0,0> , < 2,5,T> )
      )
  #end
#end

#macro IC_Thickness()
  (#ifdef(IC_Text_Thickness)
    IC_Text_Thickness
  #else
    1
  #end)
#end

#macro IC_Text ( _ICSG_String , IC_Text_Thickness , _ICSG_Offset )
  #local Start=2*x;
  #local Offset=5*x+_ICSG_Offset;

  #local C=0;
  #local Chars=0;
  #while ( C < strlen( _ICSG_String ) )
    #local C=C+1;
    #if ( asc( substr( _ICSG_String , C , 1 ) ) !=32 )
      #local Chars=Chars+1;
      #local Pos=C;
    #end
  #end

  #switch (Chars)
    #case (0)
      #error "iso_chars.inc: Empty string in IC_Text macro"
    #break
    #case (1)
      IC_Translate ( IC_Char ( substr( _ICSG_String , Pos , 1 ) ) , (Pos-1)*Offset + Start )
    #break
    #else
      #local Array = array[Chars];
      #local C=0;
      #local Chars=0;
      #while ( C < strlen( _ICSG_String ) )
        #local C=C+1;
        #if ( asc( substr( _ICSG_String , C , 1 ) ) !=32 )
          #local Array[ Chars ] = IC_Translate ( IC_Char ( substr( _ICSG_String , C , 1 ) ) , (C-1)*Offset + Start );
          #local Chars=Chars+1;
        #end
      #end
      IC_Merge_Array( Array )
    #end

#end

// End of ISO_CHARS.INC
#version iso_Chars_Inc_Temp;
#end
