// Persistence of Vision Ray Tracer Scene Description File
// File: iso_csg_test08.pov
// Vers: 3.5
// Desc: iso_sor demo
// Date: May. 2002
// Auth: Christoph Hormann
//

#version 3.5;

global_settings {
  assumed_gamma 1.0    
}

camera {
  location    <-10, 25, 10>*1.5
  direction   y
  sky         z
  up          z
  right       1.33333*x
  look_at     <0, 0, 1.7>
  angle       28
}


light_source {
  <1000, 2500, 2000>
  color rgb 1.2
} 


#include "iso_csg.inc"

#local IC_Spline1=array[12]{
  <0.1, -0.3>  
  <0.1, -0.2>  
  <0.5, 0.2>   
  <1.0, 0.4>   
  <0.3, 0.6>   
  <0.5, 0.8>   
  <0.6, 0.9>   
  <0.5, 1.0>   
  <0.1, 1.4>   
  <0.3, 1.5>   
  <0.1, 1.7>  
  <0.1, 2.0>
}  

#local IC_Spline2=array[9]{
  <0.1, -0.3>  
  <0.1, -0.2>  
  <1.0, 0.2>   
  <0.2, 0.4>   
  <0.6, 1.0>   
  <0.1, 1.5>   
  <0.6, 1.8>   
  <0.0, 1.9>  
  <0.0, 2.1>
}
     
#local IC_Spline3=array[9]{
  <0.05, 0.0>
  <0.05, 0.1>
  <0.3, 0.36>
  <0.05, 1.5>
  <0.14, 1.6>
  <0.05, 1.7>
  <0.08, 1.8>
  <0.0, 1.9>  
  <0.0, 2.0>
}

#declare fn_radial = function(x, z, y) { sin(12*atan2(x, y))*sqrt(x*x+y*y) }     
#declare fn_radial2 =function(x, z, y) { sin( 5*atan2(x, y))*sqrt(x*x+y*y) }     
#declare fn_screw =  function(x, z, y) { sin(12*atan2(x, y)+z*20)*sqrt(x*x+y*y)*3 }

#declare fn_shape1 = IC_Sor(IC_Spline1,IC_Open)
#declare fn_Iso1 = function {
  fn_shape1(x, y, z)
  + fn_radial(x, y, z)*0.07
} 

#declare fn_shape2 = IC_Sor(IC_Spline2,IC_Open)
#declare fn_Iso2 = function {
  fn_shape2(x, y, z)
  + fn_radial(x, y, z)*0.07
}  

#declare fn_shape3 = IC_Sor(IC_Spline1,IC_Open)
#declare fn_Iso3 = function {
  fn_shape3(x, y, z) 
  + fn_radial2(x, y, z)*0.12 
}   

#declare fn_shape4 = IC_Sor(IC_Spline3,IC_Open)
#declare fn_Iso4 = function {
  fn_shape4(x, y, z) 
  + fn_screw(x, y, z)*0.03
}
    
     
isosurface {
  function { fn_Iso1(x, z, y) }
  max_gradient 4.2
  contained_by { box { <-1.1, -1.1, -0.2>, <1.1, 1.1, 1.7> } }  
  
  texture {
    pigment { rgb <0, 0.2, 1.1> }   
    finish { specular 0.3 }
  }
  
  scale 4.8 
  translate -3.0*x
}  
  
            
isosurface {
  function { fn_Iso2(x, z, y) }
  max_gradient 7
  contained_by { box { <-1.1, -1.1, -0.2>, <1.1, 1.1, 2.0> } }  
  
  texture {
    pigment { rgb <1.1, 0.2, 0> }  
    finish { specular 0.3 }
  }
  
  scale 4.6
  translate 3.8*x
}  

#declare Obj1=
isosurface {
  function { fn_Iso3(x, z, y) }
  max_gradient 5
  contained_by { box { <-1.1, -1.1, -0.2>, <1.1, 1.1, 1.7> } }  
  
  texture {
    pigment { color rgb <0.05, 0.5, 0.2> }
    finish { specular 0.3 }
  }
  
  rotate 120*y
  translate -2.8*x
}

union {
  object { Obj1 }
  object { Obj1 rotate 1*(360/5)*z } 
  object { Obj1 rotate 2*(360/5)*z } 
  object { Obj1 rotate 3*(360/5)*z }  
  object { Obj1 rotate 4*(360/5)*z } 
  translate 7*y - 0.5*x  
}    
   
isosurface {
  function { fn_Iso4(x, z, y) }
  max_gradient 2.5
  contained_by { box { <-0.4, -0.4, -0.2>, <0.4, 0.4, 2> } }  
  
  texture {
    pigment { color rgb 1 }
    finish { specular 0.3 }
  }
  
  scale 4.8
  translate 7*y - 0.5*x 
}   

plane { 
  z, -1   
  texture {
    pigment { rgb <1, 0.78, 0.7> }
  }  
}  